@@ -1,13 +1,13 @@
-import os
-from pathlib import Path
-
+import logging
 import subprocess
+from pathlib import Path
 
 
 def install_script(path: Path):
-    print(path)
     if (path/'pyproject.toml').exists():
 
+        logging.debug(f'pyproject.toml found, running poetry install')
         p = subprocess.Popen(['poetry', 'install'], cwd=path.absolute())
         p.wait()
-        print('bla')
\ No newline at end of file
+    else:
+        logging.debug(f'No pyproject.toml found, skipping {path}')
\ No newline at end of file
